export function useInputEditor() {
  const primeInputWithOptionNames = ["CascadeSelect", "Listbox", "MultiSelect", "RadioButton", "Select", "SelectButton", "TreeSelect"];
  const primeInputNames = [...primeInputWithOptionNames, "AutoComplete", "Checkbox", "ColorPicker", "DatePicker", "Editor", "InputMask", "InputNumber", "InputOtp", "InputText", "Knob", "Password", "Rating", "Slider", "Textarea", "ToggleButton", "ToggleSwitch"].sort();
  const primeOutputNames = ["OutputBoolean", "OutputDate", "OutputDuration", "OutputLink", "OutputList", "OutputNumber", "OutputReference", "OutputText"];
  function editorDataToSchema(data) {
    if (!data)
      return {};
    const formkitInput = data?._dollar_formkit;
    let tempData = {};
    if (data.prime && Array.isArray(data.prime) && data.prime.length > 0) {
      const mapped = data.prime.filter((entry) => entry && typeof entry === "object" && "prime_key" in entry && "prime_value" in entry).map((entry) => {
        const key = entry.prime_key || "";
        let value = entry.prime_value;
        if (formkitInput === "primeInputOtp" && key === "length" && value !== void 0) {
          value = Number(value);
        }
        return [key, value];
      });
      tempData = Object.assign({}, ...mapped.map(([key, val]) => ({ [key]: val })));
    }
    const readonlyValue = data.readonly === true ? true : void 0;
    const disabledValue = data.disabled === true ? true : void 0;
    const preserveValue = data.preserve === true ? true : void 0;
    const defaultObject = {
      readonly: readonlyValue,
      disabled: disabledValue,
      preserve: preserveValue
    };
    let outerClass = "";
    if (data.outerClass)
      outerClass = `${outerClass} ${data.outerClass}`.trim();
    let wrapperClass = "";
    if (data.wrapperClass)
      wrapperClass = `${wrapperClass} ${data.wrapperClass}`.trim();
    let innerClass = "";
    if (data.innerClass)
      innerClass = `${innerClass} ${data.innerClass}`.trim();
    const undefinedObject = {
      prime: void 0,
      schemaResultFormKey: void 0,
      _dollar_formkit: void 0,
      slots: void 0,
      selectButton: void 0
    };
    const useOptions = formkitInput ? primeInputWithOptionNames.map((s) => `prime${s}`).includes(formkitInput) : false;
    let result = {};
    if (useOptions) {
      result = {
        ...data,
        $formkit: formkitInput,
        ...tempData,
        ...undefinedObject,
        ...defaultObject,
        outerClass,
        wrapperClass,
        innerClass,
        optionLabel: "label",
        optionValue: "value"
      };
    } else {
      result = {
        ...data,
        $formkit: formkitInput,
        ...tempData,
        ...undefinedObject,
        ...defaultObject,
        outerClass,
        wrapperClass,
        innerClass,
        options: void 0
      };
    }
    for (const key in result) {
      const value = result[key];
      if (value !== null && value !== void 0 && typeof value === "string") {
        if (value.trim().length === 0)
          result[key] = void 0;
      }
    }
    return result;
  }
  function dataToSchema(data) {
    if (!data)
      return {};
    const schema = editorDataToSchema(data);
    if (schema?.options && Array.isArray(schema.options)) {
      const options = schema.options.map((o) => o ? JSON.parse(JSON.stringify(o)) : {});
      return { ...schema, options };
    } else {
      return schema;
    }
  }
  function editorDataToJson(data) {
    if (!data)
      return "{}";
    return JSON.stringify(dataToSchema(data));
  }
  function objectToString(data) {
    if (!data)
      return "{}";
    return `{${Object.entries(data).map(([key, value]) => {
      if (key === "options" && Array.isArray(value) && value.length > 0) {
        let result = "[";
        value.forEach((o) => {
          if (o && typeof o === "object") {
            result = `${result + objectToString(o)}, `;
          }
        });
        return `${key}: ${result.substring(0, result.length - 2)}]`;
      } else if (key === "primeInputOtp") {
        return `${key}: ${value}`;
      } else {
        return `${key}: '${value}'`;
      }
    }).join()}}`;
  }
  function editorDataToObject(data) {
    if (!data)
      return "{}";
    try {
      const jsonData = editorDataToJson(data);
      return objectToString(JSON.parse(jsonData));
    } catch (error) {
      console.error("Error in editorDataToObject:", error);
      return "{}";
    }
  }
  function schemaToEditorData(schema) {
    if (!schema)
      return {};
    const formkitInput = schema?.$formkit;
    return { ...schema, _dollar_formkit: formkitInput };
  }
  return {
    primeInputNames,
    primeOutputNames,
    editorDataToSchema,
    editorDataToJson,
    editorDataToCode: editorDataToObject,
    schemaToEditorData
  };
}
